pub struct UserConfig {
pub jan_dir: Option<String>,
pub spec_root: Option<String>,
pub jan_dir_source_url: Option<String>,
pub jan_dir_sha256: Option<String>,
}Fields
jan_dir: Option<String>Preferred directory containing a jan YAML tree (absolute path when saved).
spec_root: Option<String>Entry YAML file name inside jan_dir (e.g. scripts.spec.yaml).
jan_dir_source_url: Option<String>When the preferred tree came from a remote bundle, the source HTTPS URL.
jan_dir_sha256: Option<String>SHA256 of the remote bundle zip used to populate jan_dir.