CommandNode

Struct CommandNode 

pub struct CommandNode {
    pub os: Vec<String>,
    pub about: String,
    pub path: Option<String>,
    pub dependencies: Vec<String>,
    pub requires: Vec<String>,
    pub env: BTreeMap<String, String>,
    pub cron: Vec<String>,
    pub commands: BTreeMap<String, CommandNode>,
    pub exec: Option<ExecSpec>,
}

Fields

os: Vec<String>

If non-empty, this command and its subtree are only offered on these platforms (linux, macos, windows, …). darwin is accepted as an alias for macos.

about: Stringpath: Option<String>

Directory prepended to PATH when this script (or a descendant leaf) runs.

dependencies: Vec<String>

Other script names whose path directories are prepended before this one runs.

requires: Vec<String>

External binaries that must be on PATH (e.g. fzf, jq) before the leaf runs.

env: BTreeMap<String, String>

Environment variables set on the child process (later nodes in the chain override earlier keys).

cron: Vec<String>

Optional crontab schedule(s). When set, jan cron runs this script’s run leaf whenever the local time matches any expression.

commands: BTreeMap<String, CommandNode>exec: Option<ExecSpec>

Implementations

Source

impl CommandNode

pub fn is_leaf_exec(&self) -> bool

pub fn validate(&self, path: &str) -> Result<()>